/*BINFMTCXX:
 */
#include <iostream>
#include <boost/geometry.hpp>
#include <boost/geometry/index/rtree.hpp>
#include <sys/time.h> // todo: use boost or std::chrono

namespace bg = boost::geometry;
namespace bgm = bg::model;
namespace bgi = bg::index;
using namespace std;

// used types

typedef bgm::point<double, 2, bg::cs::cartesian> P;
typedef bgm::linestring<P> LS;
typedef bgm::box<P> B;
typedef pair<B, unsigned> value_type;
typedef bgi::rtree<value_type, bgi::linear<8, 3> > RT;

uint64_t timestamp()
{
  timeval s;
  gettimeofday(&s,NULL);
  return uint64_t(s.tv_sec)*1000000+uint64_t(s.tv_usec);
}

int
main(int argc, char* argv[]) {
  RT t;
  P p(1001875, 6190443);
  unsigned linestrings=0;
  while (cin.good()) {
    while (cin.peek()=='#') {
      string dummy;
      getline(cin, dummy);
    }
    unsigned points;
    cin >> points;
    if (!cin.good()) break;
    LS l;
    while (points-- > 0) {
      double x,y;
      cin >> x >> y;
      if (!cin.good()) break;
      bg::append(l, P(x,y));
    }
    B b;
    bg::envelope(l, b);
    t.insert(value_type(b, linestrings));
    ++linestrings;
  }
  cerr << "linestrings=" << linestrings << endl;
  cerr << "t.size()=" << t.size() << endl;
  {
    uint64_t start=timestamp();
    RT::const_query_iterator it = t.qbegin(bgi::nearest(p, 100));
    cerr << (timestamp()-start) << "usec" << endl;
  }
  {
    uint64_t start=timestamp();
    RT::const_query_iterator it = t.qbegin(bgi::nearest(p, t.size()));
    cerr << (timestamp()-start) << "usec" << endl;
  }
}
